from typing import Dict, Any

from fastapi import HTTPException
from fastapi.routing import APIRouter
from orchestrator.services import processes
from pydantic import BaseModel

from gso.products.product_blocks.site import SiteTier

router = APIRouter()


class SiteImport(BaseModel):
    site_name: str
    site_city: str
    site_country: str
    site_country_code: str
    site_latitude: float
    site_longitude: float
    site_bgp_community_id: int
    site_internal_id: int
    site_tier: SiteTier


@router.post("/", tags=["Import"])
def import_site(site: SiteImport) -> Dict[str, Any]:
    """
    Import site by running the import_site workflow.
    """
    pid = processes.start_process("import_site", [site.dict()])
    if pid is None:
        raise HTTPException(status_code=500, detail="Failed to start the process.")

    process = processes._get_process(pid)  # pylint: disable=protected-access
    if process.last_status == "failed":
        raise HTTPException(
            status_code=500, detail=f"Process {pid} failed because of an internal error.")
    return {"pid": str(pid)}
